"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = (got) => {
    return {
        async list() {
            return await got.get(`rooms`).json();
        },
        async get({ id }) {
            return await got.get(`rooms/${id}`).json();
        },
        async create({ name, icon, color, }) {
            return await got
                .post(`rooms`, {
                json: {
                    name,
                    icon,
                    color,
                },
            })
                .json();
        },
        async delete({ id }) {
            await got.delete(`rooms/${id}`);
        },
        async update({ id, name, icon, color }) {
            await got
                .put(`rooms/${id}`, {
                json: {
                    name,
                    icon,
                    color,
                },
            })
                .json();
        },
        async moveDevices({ id, deviceIds, }) {
            await got
                .patch(`rooms/${id}/devices`, {
                json: {
                    deviceIds,
                },
            })
                .json();
        },
        async setIsOn({ id, deviceType, isOn, }) {
            await got
                .patch(`devices/set/${id}`, {
                searchParams: {
                    deviceType,
                },
                json: [
                    {
                        attributes: {
                            isOn,
                        },
                    },
                ],
            })
                .json();
        },
        async setAttributes({ id, deviceType, attributes, transitionTime, }) {
            await got
                .patch(`devices/room/${id}`, {
                searchParams: {
                    deviceType,
                },
                json: [
                    {
                        attributes,
                        transitionTime,
                    },
                ],
            })
                .json();
        },
    };
};
